########################
Keithley 2000 Multimeter
########################

.. autoclass:: pymeasure.instruments.keithley.Keithley2000
    :members:
    :show-inheritance:
    :inherited-members: CommonBase
